class IdentifierError(Exception):
    pass


class CheckDigitError(Exception):
    pass


class IdentifierEncodingError(Exception):
    pass


class IdentifierDecodingError(Exception):
    pass


class IndentifierFormatError(Exception):
    pass


class IndentifierFormatKeyError(Exception):
    pass


class SubjectIdentifierError(Exception):
    pass


class ResearchIdentifierError(Exception):
    pass


class BirthModelError(Exception):
    pass
